This is a firebot library to connect to Firebots API. <br>

```
pip install firebotpy
```

https://firebot.app/
From Firebots Website: <br>
"Firebot is a fully featured open-source bot that can help level up your streams." <br>

# Change Log

## 2.31 (16/12/2021)

-Add or remove currency from all online viewers <br>
-Add or remove currency from a specific role <br>

## 2.29 (13/12/2021)

-Added whisper chat from the bot or streamer account <br>
-Added duration for custom variables (default is 0) <br>
-Added getting the value of a counter <br>

## 2.281 (12/12/2021)

-Added set roles for users <br>
-Added remove all users from roles <br>
-Added enable and disable timer <br>
-Added add and remove users to VIP roles <br>
-Added ban and unban users <br>
-Added change scene <br>
-Fixed get_status function <br>

## 2.26 (09/12/2021)

-First Release <br>
